# Generated by Django 4.1.2 on 2023-01-15 22:34

from django.db import migrations, models

import django_q.models


class Migration(migrations.Migration):
    dependencies = [
        ("django_q", "0015_alter_schedule_schedule_type"),
    ]

    operations = [
        migrations.AddField(
            model_name="schedule",
            name="intended_date_kwarg",
            field=models.CharField(
                blank=True,
                help_text="Name of kwarg to pass intended schedule date",
                max_length=100,
                null=True,
                validators=[django_q.models.validate_kwarg],
            ),
        ),
    ]
